@@ -1,13 +1,11 @@
 from typing import List
 
-import requests
-
 import pyscrapers.core.utils
 
 
-def scrape_travelgirls(user_id: str, cookies) -> List[str]:
+def scrape_travelgirls(user_id: str, session) -> List[str]:
     main_url = 'https://www.travelgirls.com/member/{user_id}'.format(user_id=user_id)
-    r = requests.get(main_url, cookies=cookies)
+    r = session.get(main_url)
     root = pyscrapers.core.utils.get_html_dom_content(r)
 
     urls = []
