@@ -3,6 +3,7 @@ Module that handles the interaction with the youtube_dl library
 
 References:
 - https://github.com/ytdl-org/youtube-dl/blob/master/README.md#embedding-youtube-dl
+- https://github.com/ytdl-org/youtube-dl/blob/3e4cedf9e8cd3157df2457df7274d0c842421945/youtube_dl/YoutubeDL.py#L137-L312
 """
 import os
 from typing import List
@@ -36,6 +37,7 @@ def youtube_dl_download_urls(urls: List[str], folder: str) -> None:
     ydl_opts = {
         'format': 'bestaudio/best',
         # 'logger': MyLogger(),
+        'nooverwrites': True,
         'outtmpl': os.path.join(folder, '%(title)s-%(id)s.%(ext)s'),
     }
     with youtube_dl.YoutubeDL(ydl_opts) as ydl:
